import {ComponentMeta, ComponentStoryObj} from '@storybook/react'

import {Heading, type HeadingProps} from '.'

type HeadingStoryObj = ComponentStoryObj<typeof Heading>

export default {
    title: 'Components/Heading',
    component: Heading,
    args: {
        children: 'Heading'
    },
    argTypes: {
        size: {
            options: ['sm', 'md', 'lg', 'xl'] as HeadingProps['size'][],
            defaultValue: 'md',
            name: 'Size',
            control: {
                type: 'inline-radio'
            }
        },
        asChild: {
            table: {
                disable: true
            }
        },
        className: {
            table: {
                disable: true
            }
        },
    }
} as ComponentMeta<typeof Heading>

export const Default: HeadingStoryObj = {}

export const AsLink: HeadingStoryObj = {
    args: {
        asChild: true,
        children: (
            <a href="">Heading as anchor</a>
        )
    },
    argTypes: {
        children: {
            table: {
                disable: true
            }
        }
    }
}

export const AsH1: HeadingStoryObj = {
    args: {
        asChild: true,
        children: (
            <h1>Heading as h1</h1>
        )
    }
}