import { Slot } from "@radix-ui/react-slot";
import {clsx} from "clsx";
import { ReactNode, InputHTMLAttributes, ButtonHTMLAttributes } from "react"

interface TextInputRootProps {
    children: ReactNode;
}

function TextInputRoot({children}: TextInputRootProps){
    return (
        <div 
            className="flex overflow-hidden rounded-md items-center w-full focus-within:ring-[.5px] ring-rose-700 bg-gray-800 h-12"
        >
            {children}
        </div>
    )
}

interface TextInputInputProps extends InputHTMLAttributes<HTMLInputElement> {}
function TextInputInput(props: TextInputInputProps){
    return (
        <input 
            className="flex-1 outline-none h-full placeholder:text-gray-500 text-gray-100 bg-transparent px-2"
            {...props}
        />
    )
}

interface TextInputButtonProps extends ButtonHTMLAttributes<HTMLButtonElement> {}
function TextInputButton({className, ...props}: TextInputButtonProps) {
    return (
        <button
            className={clsx(
                'bg-rose-700 text-gray-100 h-full px-2',
                className,
            )} 
            {...props} 
        />
    )
}

interface TextInputIconProps {
    children: ReactNode;
}
function TextInputIcon(props: TextInputIconProps){
    return (
        <Slot className="text-gray-500 h-6 w-6 font-bold mx-2">
            {props.children}
        </Slot>
    )
}

export const TextInput = {
    Root: TextInputRoot,
    Input: TextInputInput,
    Button: TextInputButton,
    Icon: TextInputIcon
}